.. _index:

.. finufft documentation master file - latex only.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   Barnett 8/27/20: split this out as separate latexindex.rst.
   Also see latex section of conf.py for tocdepth override, etc.

:orphan:

   
Flatiron Institute Nonuniform Fast Fourier Transform
=====================================================

.. the toctree seems to have to precede any text for latex chapters correct
   numbering. Note that ch.1 is now the overview (unlike in index.rst):

.. toctree::
	   
   overview
   install
   dirs
   math
   cex           
   c
   opts
   error
   trouble
   tut
   fortran          
   matlab
   python
   julia
   changelog
   devnotes           
   related
   users
   ackn
   refs
